@@ -31,7 +31,7 @@
         (theImage (if (= inCopy TRUE)
                       (car (gimp-image-duplicate inImage))
                       inImage))
-        (theLayer (car (gimp-image-get-active-layer theImage)))
+        (theLayer (aref (cadr (gimp-image-get-selected-layers theImage)) 0))
         (n 0)
         (ang (* (/ 360 inFrames)
                 (if (= inFromLeft TRUE) 1 -1) ))
@@ -49,7 +49,8 @@
                                         (number->string (- inFrames n) 10)
                                         " (replace)"))
     (plug-in-map-object RUN-NONINTERACTIVE
-                        theImage theFrame    ; mapping
+                        theImage             ; mapping image
+                        1 (vector theFrame)  ; mapping drawables
                         1                    ; viewpoint
                         0.5 0.5 2.0          ; object pos
                         0.5 0.5 0.0          ; first axis
